@@ -31,10 +31,7 @@ extern "C"
 #undef BIG_ENDIAN
 #endif
 
-//#include "ADM_colorspace/colorspace.h"
-
 #include "ADM_codecs/ADM_codec.h"
-#include "ADM_codecs/ADM_mjpeg.h"
 #include "ADM_codecs/ADM_codecNull.h"
 #include "ADM_codecs/ADM_uyvy.h"
 
@@ -44,15 +41,6 @@ extern "C"
 #include "ADM_codecs/ADM_ffmp43.h"
 #endif
 
-#ifdef USE_DIVX
-#include "ADM_codecs/ADM_divx4.h"
-#endif
-
-#ifdef USE_THEORA
-#include "ADM_codecs/ADM_theora_dec.h"
-#endif
-
-
 #include "ADM_assert.h"
 #include "prefs.h"
 
@@ -355,12 +343,16 @@ if (fourCC::check (fcc, (uint8_t *) "MJPG")
 #endif
 
     }
-  if (fourCC::check (fcc, (uint8_t *) "YV12")
-      || fourCC::check (fcc, (uint8_t *) "I420"))
+  if (fourCC::check (fcc, (uint8_t *) "YV12"))
     {
       printf ("\n using null codec\n");
       return (decoders *) (new decoderNull (w, h));
     }
+  if (fourCC::check (fcc, (uint8_t *) "I420"))
+  {
+	  printf ("\n using I420 codec\n");
+	  return (decoders *) (new decoderI420(w, h));
+  }
   if (fourCC::check (fcc, (uint8_t *) "UYVY"))
     {
       printf ("\n using uyvy codec\n");
