@@ -18,18 +18,15 @@
 #if  defined( __FreeBSD__ ) || defined(__APPLE__)
 #include <sys/types.h>
 #endif
-#include <stdlib.h>
 
-#include <string.h>
-//#include <math.h>
-#include "ADM_utilities/default.h"
+#include "ADM_default.h"
 #include "avifmt.h"
 #include "avifmt2.h"
-#include "ADM_utilities/fourcc.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "fourcc.h"
+
 #include "ADM_codecs/ADM_codec.h"
 #include "ADM_codecs/ADM_uyvy.h"
-#include <ADM_assert.h>
+
 uint8_t
   decoderUYVY::uncompress (ADMCompressedImage * in, ADMImage * out)
 {
