@@ -13,19 +13,14 @@
  ***************************************************************************/
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <math.h>
 
-#include <string.h>
-
-#include "math.h"
-
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 #include "fourcc.h"
-#include "ADM_toolkit/toolkit.hxx"
+
 
 #include "ADM_mkv.h"
 
