@@ -126,6 +126,9 @@
    MKTAG(MKV_DISPLAY_HEIGHT,0x54BA,ADM_MKV_TYPE_UINTEGER),
    MKTAG(MKV_FLAG_INTERLACED,0x9A,ADM_MKV_TYPE_UINTEGER),
 
+   MKTAG(MKV_CRC32,0xBF,ADM_MKV_TYPE_BINARY),
+   MKTAG(MKV_PREV_SIZE,0xAB,ADM_MKV_TYPE_UINTEGER),
+   MKTAG(MKV_POSITION,0xA7,ADM_MKV_TYPE_UINTEGER),
 
          //*************************
    MKTAG(MKV_MAX,0xFFFF,ADM_MKV_TYPE_UNKNOWN)
