@@ -16,17 +16,12 @@
  ***************************************************************************/
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <math.h>
-
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_assert.h"
 
 
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit/filesel.h"
+
+#include "DIA_fileSel.h"
 #include "fourcc.h"
 #include "ADM_userInterfaces/ADM_commonUI/DIA_working.h"
 
