@@ -16,13 +16,9 @@
  ***************************************************************************/
 
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include "config.h"
 #include <math.h>
-
-#include "default.h"
+#include "ADM_default.h"
 #include "avifmt.h"
 #include "avifmt2.h"
 
@@ -30,10 +26,7 @@
 #include "ADM_audio/aviaudio.hxx"
 
 #include "fourcc.h"
-#include "ADM_assert.h"
-
-
-#include "ADM_toolkit/toolkit.hxx"
+#include "DIA_coreToolkit.h"
 #include "ADM_userInterfaces/ADM_commonUI/DIA_working.h"
 
 
@@ -403,7 +396,7 @@ char *start;
                                                 ADM_assert(0);
                                         }
                                         str--;
-#ifdef ADM_WIN32                                        
+#ifdef __WIN32                                        
                                         sscanf(str,"%c:%I64x,%I64x,%x",&imgtype,&imgabs,&imgrel,&imgsize);
 #else                                      
                                         sscanf(str,"%c:%llx,%llx,%x",&imgtype,&imgabs,&imgrel,&imgsize);
@@ -661,7 +654,8 @@ dmxIndex *idx;
 
         if(framenum>=_nbFrames) return 0;
         
-        img->flags=getFlags(framenum,&f);
+        if(!getFlags(framenum,&f)) return 0;
+        img->flags=f;
 
         idx=&(_index[framenum]);
         img->dataLength=idx->size;
