@@ -11,32 +11,24 @@
  *                                                                         *
  ***************************************************************************/
 
-
-#include "config.h"
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <strings.h>
-#include <unistd.h>	/* access(), R_OK */
-#include <errno.h>	/* errno, ENOENT */
-#include <dirent.h>
-
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_osSupport/ADM_quota.h"
-
 #include "config.h"
+#include <list>
+using namespace std;
 
 #ifdef USE_LIBXML2
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #endif
-#include <ADM_assert.h>
+#include "ADM_default.h"
+
+#include "ADM_osSupport/ADM_quota.h"
+#include <unistd.h>	/* access(), R_OK */
+#include <errno.h>	/* errno, ENOENT */
+#include <dirent.h>
 
 #undef free
 extern char *ADM_getBaseDir(void);
 #define CONFIG "config"
-extern char *PathCanonize(const char *tmpname);
 extern int  qxmlSaveFormatFile(const char *filename, xmlDocPtr cur, int format);
 static char *checkDirAccess(char *home);
 extern char *ADM_escape(const ADM_filename *incoming);
@@ -82,10 +74,6 @@ static opt_def opt_defs [] = {
 	{"codecs.dvd.matrix",		UINT,	"0",	NULL,	"0",	"99999"},
 	{"codecs.dvd.gopsize",		UINT,	"12",	NULL,	"0",	"99999"},
 	{"codecs.dvd.maxbitrate",		UINT,	"9000",	NULL,	"0",	"9900"	},
-	{"codecs.xvid.enctype",		UINT,	"0",	NULL,	"0",	"99999"},
-	{"codecs.xvid.quantizer",		UINT,	"4",	NULL,	"2",	"32"	},
-	{"codecs.xvid.bitrate",		UINT,	"1500000",NULL,	"17",	"5900000"},
-	{"codecs.xvid.finalsize",	UINT,	"700",	NULL,	"0",	"3999"	},
 	{"codecs.preferredcodec",		STRING,"FFmpeg4",NULL, NULL, NULL },
 #ifdef __WIN32
 	{"filters.subtitle.fontname",		FILENAME,"C:\\Windows\\Fonts\\arial.ttf",NULL, NULL, NULL },
@@ -99,7 +87,10 @@ static opt_def opt_defs [] = {
 	{"filters.subtitle.vpercent",		INT,	"0",	NULL,	"0",	"255"	},
 	{"filters.subtitle.selfadjustable",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"filters.subtitle.usebackgroundcolor",		UINT,	"0",	NULL,	"0",	"1"	},
-	{"settings.mpegsplit",	UINT,	"790",	NULL,	"400",	"5000"	},
+	{"filters.avsfilter.avs_script",		FILENAME,"",	NULL, NULL, NULL },
+	{"filters.avsfilter.avs_loader",		FILENAME,"",	NULL, NULL, NULL },
+	{"filters.avsfilter.pipe_timeout",		UINT,	"10",	NULL,	"1",	"30"	},
+	{"filters.avsfilter.debug_msg",		UINT,	"1",	NULL,	"0",	"1"	},
 #ifdef __WIN32
 	{"device.audiodevice",		STRING,"WIN32",NULL, NULL, NULL },
 #else
@@ -113,21 +104,21 @@ static opt_def opt_defs [] = {
 	{"lastfiles.file2",		FILENAME,"",	NULL, NULL, NULL },
 	{"lastfiles.file3",		FILENAME,"",	NULL, NULL, NULL },
 	{"lastfiles.file4",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastfiles.file5",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastfiles.file6",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastproject.file1",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastproject.file2",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastproject.file3",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastproject.file4",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastproject.file5",		FILENAME,"",	NULL, NULL, NULL },
+	{"lastproject.file6",		FILENAME,"",	NULL, NULL, NULL },
 	{"lastdir_read",		FILENAME,"",	NULL, NULL, NULL },
 	{"lastdir_write",		FILENAME,"",	NULL, NULL, NULL },
-	{"lame_cli",		STRING,"",	NULL, NULL, NULL },
-	{"pipe_cmd",		STRING,"",	NULL, NULL, NULL },
-	{"pipe_param",		STRING,"",	NULL, NULL, NULL },
-	{"lame_path",		STRING,"",	NULL, NULL, NULL },
-	{"toolame_path",		STRING,"",	NULL, NULL, NULL },
-	{"lvemux_path",		STRING,"",	NULL, NULL, NULL },
-	{"requant_path",		STRING,"",	NULL, NULL, NULL },
 	{"message_level",		UINT,	"2",	NULL,	"0",	"2"	},
 	{"feature.swap_if_A_greater_than_B",		UINT,	"1",	NULL,	"0",	"1"	},
 	{"feature.svcdres.preferedsourceratio",		STRING,"1:1",	NULL, NULL, NULL },
 	{"feature.saveprefsonexit",		UINT,	"1",	NULL,	"0",	"1"	},
 	{"feature.ignoresavedmarkers",		UINT,	"0",	NULL,	"0",	"1"	},
-	{"feature.use_lavcodec_mpeg2",		UINT,	"1",	NULL,	"0",	"1"	},
 	{"feature.disable_nuv_resync",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.tryautoidx",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.use_odml",		UINT,	"0",	NULL,	"0",	"1"	},
@@ -135,16 +126,12 @@ static opt_def opt_defs [] = {
 	{"feature.reuse_2pass_log",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.audiobar_uses_master",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.threading.lavc",		UINT,	"0",	NULL,	"0",	"32"	},
-	{"feature.threading.x264",		UINT,	"0",	NULL,	"0",	"32"	},
-	{"feature.threading.xvid",		UINT,	"0",	NULL,	"0",	"32"	},
 	{"feature.cpu_caps",		UINT,	"4294967295",NULL,	"0",	"4294967295"},
 	{"feature.mpeg_no_limit",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.auto_buildmap",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.auto_rebuildindex",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.auto_unpack",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"downmixing.prologic",		UINT,	"2",	NULL,	"0",	"2"	},
-	{"filters.autoload.path",		STRING,"/tmp/",NULL, NULL, NULL },
-	{"filters.autoload.active",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.alternate_mp3_tag",		UINT,	"1",	NULL,	"0",	"1"	},
 	{"feature.global_glyph.active",		UINT,	"1",	NULL,	"0",	"1"	},
 	{"feature.global_glyph.name",		STRING,"",	NULL, NULL, NULL },
@@ -153,7 +140,7 @@ static opt_def opt_defs [] = {
 	{"priority.playback",		UINT,	"0",	NULL,	"0",	"4"	}
 };
 
-int num_opts = 81;
+int num_opts = 76;
 // </prefs_gen>
 
 #ifdef USE_LIBXML2
@@ -246,9 +233,12 @@ void set_content(const char *option, xmlNodePtr x){
 #include "prefs.h"
 
 preferences::preferences(){
-	internal_lastfiles[0] = internal_lastfiles[1] = NULL;
-	internal_lastfiles[2] = internal_lastfiles[3] = NULL;
-	internal_lastfiles[4] = NULL;
+	for (int index = 0; index < 7; index++)
+		internal_lastfiles[index] = NULL;
+
+	for (int index = 0; index < 7; index++)
+		_lastProjects[index] = NULL;
+
 	#ifdef USE_LIBXML2
 	xdoc = NULL;
 	#endif
@@ -256,10 +246,17 @@ preferences::preferences(){
 
 preferences::~preferences(){
   unsigned int idx;
-	for( idx=0; idx < 4; idx++ ){
+	for( idx=0; idx < 6; idx++ ){
 		if( internal_lastfiles[idx] )
 			ADM_dealloc(internal_lastfiles[idx]);
 	}
+
+	for (int idx = 0; idx < 6; idx++)
+	{
+		if (_lastProjects[idx])
+			ADM_dealloc(_lastProjects[idx]);
+	}
+
 	#ifdef USE_LIBXML2
 	if( xdoc )
 		xmlFreeDoc(xdoc);
@@ -433,7 +430,7 @@ int preferences::save_xml_to_file(){
         strcat(rcfile,CONFIG);
 
 
-#if defined(ADM_WIN32)
+#if defined(__MINGW32__)
 	xmlSetDocCompressMode(xdoc,9);
 	if( xmlSaveFormatFile(rcfile,xdoc,1) == -1 ){
            fprintf(stderr,"\ncan't save xml tree to file. Filesystem full?\n\n");
@@ -850,7 +847,7 @@ int preferences::set_lastfile(const char* file){
 		fprintf(stderr,"Prefs: set_lastfile(NULL) called\n");
 		return RC_FAILED;
 	}
-	internal_file = PathCanonize(file);
+	internal_file = ADM_PathCanonize(file);
 	if( !internal_file ){
 		fprintf(stderr,"Prefs: set_lastfile(): PathCanonize() returns NULL\n");
 		return RC_FAILED;
@@ -863,42 +860,32 @@ int preferences::set_lastfile(const char* file){
 	PRT_LAFI("<= LASTFILES_",2,opt_defs[LASTFILES_FILE2].current_val);
 	PRT_LAFI("<= LASTFILES_",3,opt_defs[LASTFILES_FILE3].current_val);
 	PRT_LAFI("<= LASTFILES_",4,opt_defs[LASTFILES_FILE4].current_val);
+	PRT_LAFI("<= LASTFILES_",5,opt_defs[LASTFILES_FILE5].current_val);
+	PRT_LAFI("<= LASTFILES_",6,opt_defs[LASTFILES_FILE6].current_val);
 #endif
-	// change opt_defs array
-	//
-	// ToDo:
-	// * a call with a file already in lastfiles will resort lastfiles with
-	//   the actual argument on top
-	// * a call with a file new to lastfiles will drop LASTFILE_4, move all
-	//   one step down and add the file as LASTFILE_1
-	if( opt_defs[LASTFILES_FILE4].current_val &&
-	    !strncmp(opt_defs[LASTFILES_FILE4].current_val,internal_file,strlen(opt_defs[LASTFILES_FILE4].current_val)) ){
-	  char *x = opt_defs[LASTFILES_FILE4].current_val;
-		opt_defs[LASTFILES_FILE4].current_val = opt_defs[LASTFILES_FILE3].current_val;
-		opt_defs[LASTFILES_FILE3].current_val = opt_defs[LASTFILES_FILE2].current_val;
-		opt_defs[LASTFILES_FILE2].current_val = opt_defs[LASTFILES_FILE1].current_val;
-		opt_defs[LASTFILES_FILE1].current_val = x;
-	}else if( opt_defs[LASTFILES_FILE3].current_val &&
-            !strncmp(opt_defs[LASTFILES_FILE3].current_val,internal_file,strlen(opt_defs[LASTFILES_FILE3].current_val)) ){
-          char *x = opt_defs[LASTFILES_FILE3].current_val;
-		opt_defs[LASTFILES_FILE3].current_val = opt_defs[LASTFILES_FILE2].current_val;
-                opt_defs[LASTFILES_FILE2].current_val = opt_defs[LASTFILES_FILE1].current_val;
-                opt_defs[LASTFILES_FILE1].current_val = x;
-        }else if( opt_defs[LASTFILES_FILE2].current_val &&
-            !strncmp(opt_defs[LASTFILES_FILE2].current_val,internal_file,strlen(opt_defs[LASTFILES_FILE2].current_val)) ){
-          char *x = opt_defs[LASTFILES_FILE2].current_val;
-		opt_defs[LASTFILES_FILE2].current_val = opt_defs[LASTFILES_FILE1].current_val;
-		opt_defs[LASTFILES_FILE1].current_val = x;
-	}else if( opt_defs[LASTFILES_FILE1].current_val &&
-            !strncmp(opt_defs[LASTFILES_FILE1].current_val,internal_file,strlen(opt_defs[LASTFILES_FILE1].current_val)) ){
-		; // nothing to do - always on top
-	}else{
-		if( opt_defs[LASTFILES_FILE4].current_val )
-			ADM_dealloc(opt_defs[LASTFILES_FILE4].current_val);
-		opt_defs[LASTFILES_FILE4].current_val = opt_defs[LASTFILES_FILE3].current_val;
-		opt_defs[LASTFILES_FILE3].current_val = opt_defs[LASTFILES_FILE2].current_val;
-		opt_defs[LASTFILES_FILE2].current_val = opt_defs[LASTFILES_FILE1].current_val;
-		opt_defs[LASTFILES_FILE1].current_val = ADM_strdup(internal_file);
+
+	int firstIndex = LASTFILES_FILE1;
+	int lastIndex = LASTFILES_FILE6;
+	list<char*> lastFileList;
+	int currentIndex = firstIndex;
+
+	for (int index = firstIndex; index <= lastIndex; index++)
+	{
+		if (opt_defs[index].current_val && strcmp(opt_defs[index].current_val, internal_file) != 0)
+			lastFileList.push_back(opt_defs[index].current_val);
+	}
+
+	lastFileList.push_front(ADM_strdup(internal_file));
+
+	while (!lastFileList.empty())
+	{
+		if (currentIndex <= lastIndex)
+			opt_defs[currentIndex].current_val = lastFileList.front();
+		else
+			ADM_dealloc(lastFileList.front());
+
+		lastFileList.pop_front();
+		currentIndex++;
 	}
 
 #ifdef USE_LIBXML2
@@ -933,6 +920,12 @@ int preferences::set_lastfile(const char* file){
 		q = goto_node_with_create(p, "file4");		// ->avidemux->lastfile->4
 		xmlNodeSetContent( q,
 			(xmlChar*)(opt_defs[LASTFILES_FILE4].current_val?opt_defs[LASTFILES_FILE4].current_val:""));
+		q = goto_node_with_create(p, "file5");		// ->avidemux->lastfile->5
+		xmlNodeSetContent( q,
+			(xmlChar*)(opt_defs[LASTFILES_FILE5].current_val?opt_defs[LASTFILES_FILE5].current_val:""));
+		q = goto_node_with_create(p, "file6");		// ->avidemux->lastfile->6
+		xmlNodeSetContent( q,
+			(xmlChar*)(opt_defs[LASTFILES_FILE6].current_val?opt_defs[LASTFILES_FILE6].current_val:""));
 		save_xml_to_file();
 	}
 #endif
@@ -942,6 +935,8 @@ int preferences::set_lastfile(const char* file){
 	PRT_LAFI("=> LASTFILES_",2,opt_defs[LASTFILES_FILE2].current_val);
 	PRT_LAFI("=> LASTFILES_",3,opt_defs[LASTFILES_FILE3].current_val);
 	PRT_LAFI("=> LASTFILES_",4,opt_defs[LASTFILES_FILE4].current_val);
+	PRT_LAFI("=> LASTFILES_",5,opt_defs[LASTFILES_FILE5].current_val);
+	PRT_LAFI("=> LASTFILES_",6,opt_defs[LASTFILES_FILE6].current_val);
 #endif
 	delete[] internal_file;
 	return RC_OK;
@@ -955,7 +950,7 @@ const char **preferences::get_lastfiles(void){
 #ifdef DEBUG_PREFS
 	fprintf(stderr,"Prefs: get_lastfile()\n");
 #endif
-	for( idx=0; idx < 4; idx++ ){
+	for( idx=0; idx < 6; idx++ ){
 		if( internal_lastfiles[idx] ){
 			ADM_dealloc(internal_lastfiles[idx]);
 			internal_lastfiles[idx] = NULL;
@@ -969,7 +964,11 @@ const char **preferences::get_lastfiles(void){
 		internal_lastfiles[2] = ADM_strdup(opt_defs[LASTFILES_FILE3].current_val);
 	if( opt_defs[LASTFILES_FILE4].current_val )
 		internal_lastfiles[3] = ADM_strdup(opt_defs[LASTFILES_FILE4].current_val);
-	internal_lastfiles[4] = NULL;
+	if( opt_defs[LASTFILES_FILE5].current_val )
+		internal_lastfiles[4] = ADM_strdup(opt_defs[LASTFILES_FILE5].current_val);
+	if( opt_defs[LASTFILES_FILE6].current_val )
+		internal_lastfiles[5] = ADM_strdup(opt_defs[LASTFILES_FILE6].current_val);
+	internal_lastfiles[6] = NULL;
 
 #ifdef DEBUG_PREFS
 	PRT_LAFI(0,internal_lastfiles[0]);
@@ -977,9 +976,134 @@ const char **preferences::get_lastfiles(void){
 	PRT_LAFI(2,internal_lastfiles[2]);
 	PRT_LAFI(3,internal_lastfiles[3]);
 	PRT_LAFI(4,internal_lastfiles[4]);
+	PRT_LAFI(5,internal_lastfiles[5]);
+	PRT_LAFI(6,internal_lastfiles[6]);
 #endif
 	return (const char**)internal_lastfiles;
 }
+
+const char **preferences::getLastProjects(void)
+{
+	for (int idx = 0; idx < 6; idx++)
+	{
+		if (_lastProjects[idx])
+		{
+			ADM_dealloc(_lastProjects[idx]);
+			_lastProjects[idx] = NULL;
+		}
+	}
+
+	int firstIndex = LASTPROJECT_FILE1;
+	int lastIndex = LASTPROJECT_FILE6;
+	int counter = 0;
+
+	for (int currentIndex = firstIndex; currentIndex <= lastIndex; currentIndex++)
+	{
+		if (opt_defs[currentIndex].current_val)
+			_lastProjects[counter] = ADM_strdup(opt_defs[currentIndex].current_val);
+
+		counter++;
+	}
+
+	_lastProjects[counter] = NULL;
+
+	return (const char**)_lastProjects;
+}
+
+int preferences::setLastProject(const char* file)
+{
+	if (!file)
+	{
+		fprintf(stderr, "Prefs: setLastProject(NULL) called\n");
+		return RC_FAILED;
+	}
+
+	char *internal_file = ADM_PathCanonize(file);
+
+	if (!internal_file)
+	{
+		fprintf(stderr, "Prefs: setLastProject: PathCanonize returns NULL\n");
+		return RC_FAILED;
+	}
+
+	int firstIndex = LASTPROJECT_FILE1;
+	int lastIndex = LASTPROJECT_FILE6;
+	list<char*> lastFileList;
+	int currentIndex = firstIndex;
+
+	for (int index = firstIndex; index <= lastIndex; index++)
+	{
+		if (opt_defs[index].current_val && strcmp(opt_defs[index].current_val, internal_file) != 0)
+			lastFileList.push_back(opt_defs[index].current_val);
+	}
+
+	lastFileList.push_front(ADM_strdup(internal_file));
+
+	while (!lastFileList.empty())
+	{
+		if (currentIndex <= lastIndex)
+			opt_defs[currentIndex].current_val = lastFileList.front();
+		else
+			ADM_dealloc(lastFileList.front());
+
+		lastFileList.pop_front();
+		currentIndex++;
+	}
+
+	if(!xdoc)
+	{
+		// no .avidemuxrc file or not loaded yet
+		load();          // try to load it
+
+		if (!xdoc)
+		{    // really: no .avidemuxrc file
+			save();  // generate one from internal defaults and actual changes
+
+			if(xdoc)
+				erase_blank_nodes(xdoc->children);
+		}
+	}
+
+	if (!xdoc)
+	{
+		fprintf(stderr, "Prefs: no xml document generated by load() nor save()\n");
+	}
+	else
+	{
+		// we assume a valid xml document, but maybe an older version
+		ADM_assert(xdoc->children);
+
+		xmlNodePtr p;
+		xmlNodePtr q;
+		
+		p = xdoc->children;				// ->avidemux (should be there)
+		p = goto_node_with_create(p, "lastfiles");	// ->avidemux->lastfile
+
+		q = goto_node_with_create(p, "file1");
+		xmlNodeSetContent(q, (xmlChar*)(opt_defs[LASTPROJECT_FILE1].current_val ? opt_defs[LASTPROJECT_FILE1].current_val : ""));
+
+		q = goto_node_with_create(p, "file2");
+		xmlNodeSetContent(q, (xmlChar*)(opt_defs[LASTPROJECT_FILE2].current_val ? opt_defs[LASTPROJECT_FILE2].current_val : ""));
+
+		q = goto_node_with_create(p, "file3");
+		xmlNodeSetContent(q, (xmlChar*)(opt_defs[LASTPROJECT_FILE3].current_val ? opt_defs[LASTPROJECT_FILE3].current_val : ""));
+
+		q = goto_node_with_create(p, "file4");
+		xmlNodeSetContent(q, (xmlChar*)(opt_defs[LASTPROJECT_FILE4].current_val ? opt_defs[LASTPROJECT_FILE4].current_val : ""));
+
+		q = goto_node_with_create(p, "file5");
+		xmlNodeSetContent(q, (xmlChar*)(opt_defs[LASTPROJECT_FILE5].current_val ? opt_defs[LASTPROJECT_FILE5].current_val : ""));
+
+		q = goto_node_with_create(p, "file6");
+		xmlNodeSetContent(q, (xmlChar*)(opt_defs[LASTPROJECT_FILE6].current_val ? opt_defs[LASTPROJECT_FILE6].current_val : ""));
+
+		save_xml_to_file();
+	}
+
+	delete[] internal_file;
+	return RC_OK;
+}
+
 int initPrefs(  void )
 {
   prefs = new preferences();
