@@ -14,7 +14,7 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifndef ADM_WIN32
+#ifndef __WIN32
 #include <sys/wait.h>
 #include <sys/param.h>
 #endif
@@ -26,25 +26,25 @@
 #include <string>
 #include "ADM_JSAvidemux.h"
 #include "ADM_JSGlobal.h"
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_default.h"
+#include "DIA_coreToolkit.h"
 #include "ADM_editor/ADM_outputfmt.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "adm_scanner.h" 
 #include "avi_vars.h"
 #include "gui_action.hxx"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encConfig.h"
 #include "ADM_editor/ADM_outputfmt.h"
-#include "ADM_filter/video_filters.h"
+
 #include "ADM_script/ADM_container.h"
 
 #include "ADM_JSGlobal.h"
-#include "ADM_toolkit/filesel.h"
+#include "DIA_fileSel.h"
 
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "DIA_factory.h"
 
 std::vector <std::string> g_vIncludes;
 extern char **environ;
@@ -82,6 +82,8 @@ JSBool facHex(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval
 JSBool facDirSel(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
 JSBool facButton(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
 JSBool facMatrix(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
+JSBool facNotch(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
+JSBool facThreadCount(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
 JSBool facSlider(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
 JSBool crashTest(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
 JSBool assertTest(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval);
@@ -102,23 +104,25 @@ static JSFunctionSpec adm_functions[] = {
   {"exec",          systemExecute,        3},
   {"include",          systemInclude,        1},
   {"pathOnly",          pathOnly,        1},
-  {"dialogFactoryInt",          facInt,        0},
-  {"dialogFactoryFloat",        facFloat,        0},
+  {"dialogFactoryInt",          facInt,           0},
+  {"dialogFactoryFloat",        facFloat,         0},
   {"dialogFactoryToggle",       facToggle,        0},
-  {"dialogFactoryMenu",         facMenu,        0},
-  {"dialogFactoryFileSel",      facFile,        0},
-  {"dialogFactoryBitrate",      facBitrate,        0},
-  {"dialogFactoryBar",        facBar,        0},
-  {"dialogFactoryRoText",     facRoText,        0},
-  {"dialogFactoryText",       facText,        0},
-  {"dialogFactoryTabs",       facTab,        0},
+  {"dialogFactoryMenu",         facMenu,          0},
+  {"dialogFactoryFileSel",      facFile,          0},
+  {"dialogFactoryBitrate",      facBitrate,       0},
+  {"dialogFactoryBar",        facBar,             0},
+  {"dialogFactoryRoText",     facRoText,          0},
+  {"dialogFactoryText",       facText,            0},
+  {"dialogFactoryTabs",       facTab,             0},
   {"dialogFactoryDirSel",       facDirSel,        0},
-  {"dialogFactoryFrame",       facFrame,        0},
-  {"dialogFactoryHex",       facHex,        0},
+  {"dialogFactoryFrame",       facFrame,          0},
+  {"dialogFactoryHex",       facHex,              0},
   {"dialogFactoryButton",       facButton,        0},
   {"dialogFactorySlider",       facSlider,        0},
   {"dialogFactoryMatrix",       facMatrix,        0},
-  {"crashTest",               crashTest,        0},
+  {"dialogFactoryNotch",       facNotch,		  0},
+  {"dialogFactoryThreadCount", facThreadCount,		  0},
+  {"crashTest",               crashTest,          0},
   {"assertTest",               assertTest,        0},
   {0}
 };
@@ -181,7 +185,7 @@ JSBool displayError(JSContext *cx, JSObject *obj, uintN argc,
 		return JS_FALSE;
 	char  *stringa = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
 	GUI_Verbose();
-	GUI_Alert(stringa);
+	GUI_Error_HIG("Error",stringa);
 	GUI_Quiet();
 
 	return JS_TRUE;
@@ -196,7 +200,7 @@ JSBool displayInfo(JSContext *cx, JSObject *obj, uintN argc,
 		return JS_FALSE;
 	char  *stringa = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
 	GUI_Verbose();
-	GUI_Info(stringa);
+	GUI_Info_HIG(ADM_LOG_IMPORTANT,"Info",stringa);
 	GUI_Quiet();
 	return JS_TRUE;
 }// end displayInfo
@@ -298,7 +302,7 @@ struct dirent *direntry;
 
 JSBool nextFile(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
 {
-char *n;
+const char *n;
         if(argc != 0)
                 return JS_FALSE;
 
@@ -350,7 +354,7 @@ JSBool systemExecute(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsva
 		args[i + 1] = JS_GetStringBytes(JSVAL_TO_STRING(jsValue));
 	}
 
-#ifndef __MINGW32__
+#ifndef __WIN32
 	if(getuid() == 0)
 	{// begin running as root
 		JS_ReportError(cx, "exec() disallowed while running as root.");
@@ -370,19 +374,19 @@ JSBool systemExecute(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsva
 
         enterLock();
 	// clear file descriptor table of forked process and fork
-#if defined( __linux__) || defined(__macosx__) || defined(__APPLE__)
+#if defined( __linux__) || defined(__macosx__) || defined(__APPLE__) || defined(__CYGWIN__)
 	pid_t pidRtn = fork();
 #elif defined(__FreeBSD__) || defined(__OpenBSD__)
 	pid_t pidRtn = rfork(RFPROC|RFCFDG);
 #endif
 
-#ifdef __MINGW32__
+#ifdef __WIN32
 	intptr_t pidRtn = spawnvpe(bWait ? P_WAIT : P_NOWAIT, pExecutable, args, environ);
 	#define WEXITSTATUS
 #else
 	if(pidRtn == 0)
 	{// begin child process
-#if defined( __linux__) || defined(__macosx__) || defined(__APPLE__)
+#if defined( __linux__) || defined(__macosx__) || defined(__APPLE__) || defined(__CYGWIN__)
 		close(STDIN_FILENO);
 		close(STDOUT_FILENO);
 		close(STDERR_FILENO);
@@ -435,22 +439,27 @@ JSBool systemInclude(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsva
 	// dependency loop
 	char *pTempStr = new char[PATH_MAX+1];
 
-#ifdef __MINGW32__
-	if(_fullpath(pTempStr,pIncludeFile,PATH_MAX) == NULL)
-#else
-	if(realpath(pIncludeFile,pTempStr) == NULL)
-#endif
-	{// begin can't resolve path
-		JS_ReportError(cx, "include() can't resolve the path of \"%s\".", pIncludeFile);
-		return JS_FALSE;
-	}// end can't resolve path
+	strcpy(pTempStr, pIncludeFile);
+
+	if(stat(pTempStr, &sbFileInfo) != 0)
+	{
+		char *scriptPath = ADM_getScriptPath();
+
+		strcpy(pTempStr, scriptPath);
+		strcat(pTempStr, pIncludeFile);
+		delete scriptPath;
+
+		if(stat(pTempStr, &sbFileInfo) != 0)
+		{
+			JS_ReportError(cx, "include() Can't stat \"%s\" errno(%i).", pIncludeFile, errno);
+			delete pTempStr;
+
+			return JS_FALSE;
+		}
+	}
 
 	std::string sRealPath = pTempStr;
-	if(stat(sRealPath.c_str() , &sbFileInfo) != 0)
-	{// begin can't stat file
-		JS_ReportError(cx, "include() Can't stat \"%s\" errno(%i).", sRealPath.c_str(), errno);
-		return JS_FALSE;
-	}// end can't stat file
+	delete pTempStr;
 
 	for(int i = 0;i < g_vIncludes.size();i++)
 	{// begin check previous includes
@@ -490,7 +499,7 @@ JSBool pathOnly(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rv
     return JS_FALSE;
   char *name=NULL;
   char *orgName = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
-  PathStripName(orgName);
+  ADM_PathStripName(orgName);
   /* Remove last / or last \ */
   int l=strlen(orgName);
   if(l) orgName[l-1]=0;
@@ -552,7 +561,8 @@ JSBool facToggle(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *r
 
 JSBool facMenu(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
 {
-   uint32_t tog=0;
+   uint32_t tog=4;
+   ELEM_TYPE_FLOAT f=1; 
    
     diaMenuEntry menu[]={
                              {2,   QT_TR_NOOP("No Strategy"),NULL},
@@ -561,9 +571,13 @@ JSBool facMenu(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rva
                              {7,  QT_TR_NOOP("NTSC converted from PAL"),NULL}
                           };
    diaElemMenu blend(&tog,QT_TR_NOOP("menu"),4,menu);
-    diaElem *elems[]={&blend   };
     
-  if(diaFactoryRun("Test Menu",1,elems))
+    // Link it to another
+    diaElemFloat toggle(&f,"Linked float",1,2);
+    blend.link(&(menu[1]),1,&toggle);
+    //
+diaElem *elems[]={&blend,&toggle   };
+  if(diaFactoryRun("Test Menu",2,elems))
   {
     *rval = BOOLEAN_TO_JSVAL(1);
     printf("Value : %u\n",tog);
@@ -819,6 +833,38 @@ JSBool facMatrix(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *r
   return JS_TRUE;
       
       
+}
+JSBool facThreadCount(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
+{
+	uint32_t val=1;
+	diaElemThreadCount threadcount(&val,"ThreadCount");
+      
+    diaElem *elems[]={&threadcount   };
+    
+  if(diaFactoryRun("Test ThreadCount",1,elems))
+  {
+    *rval = BOOLEAN_TO_JSVAL(1);
+    
+  }else
+    *rval = BOOLEAN_TO_JSVAL(0);
+  return JS_TRUE;
+      
+}
+JSBool facNotch(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
+{
+    
+	diaElemNotch notch(1,"Notch");
+      
+         diaElem *elems[]={&notch   };
+  if(diaFactoryRun("Test Notch",1,elems))
+  {
+    *rval = BOOLEAN_TO_JSVAL(1);
+    
+  }else
+    *rval = BOOLEAN_TO_JSVAL(0);
+  return JS_TRUE;
+      
+      
 }
 
 JSBool crashTest(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
