@@ -15,30 +15,24 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "default.h"
-
-#include <gtk/gtk.h>
+#include "ADM_toolkitGtk.h"
 #include <cmath>
 
 #include "fourcc.h"
-#include "avio.hxx"
+
 
 #include "avi_vars.h"
 
 #ifdef HAVE_ENCODER
 
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_videoFilter/ADM_vidSwissArmyKnife.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit_gtk/ADM_gladeSupport.h"
-#include "ADM_toolkit_gtk/toolkit_gtk.h"
-#include "ADM_toolkit_gtk/toolkit_gtk_include.h"
-#include "ADM_assert.h"
+
 #include "DIA_flyDialog.h"
 #include "DIA_flySwissArmyKnife.h"
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h" // for diaElemMenu etc.
-#include "ADM_filter/video_filters.h"
+#include "DIA_factory.h"
+#include "ADM_videoFilter_internal.h"
 
 #undef _
 #define _(_s) QT_TR_NOOP(_s)
