@@ -14,37 +14,23 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
 #include <math.h>
-#include <gtk/gtk.h>
 
-#include "fourcc.h"
-#include "avio.hxx"
-
-
-#include "default.h"
-#include "ADM_toolkit_gtk/toolkit_gtk.h"
-#include "ADM_toolkit_gtk/toolkit_gtk_include.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit/filesel.h"
-#include "ADM_assert.h"
+#include "ADM_toolkitGtk.h"
 
 
+#include "DIA_fileSel.h"
 
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
 
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 
 
-#include "ADM_filter/video_filters.h"
+#include "ADM_video/ADM_vidMisc.h"
+#include "avi_vars.h"
 
 void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate );
 static GtkWidget	*create_Calculator (void);  
