@@ -19,14 +19,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
-#include <gtk/gtk.h>
+#include "ADM_toolkitGtk.h"
+#include "ADM_videoFilter.h"
 
-#include "default.h"
-#include "ADM_toolkit_gtk/toolkit_gtk.h"
-#include "ADM_toolkit_gtk/toolkit_gtk_include.h"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_assert.h"
 
 #include "DIA_flyDialog.h"
 #include "DIA_flyPreview.h"
