@@ -15,26 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "ui_about.h"
-#include "default.h"
-#include "../ADM_toolkit/qtToolkit.h"
+#include "config.h"
+#include "Q_about.h"
+#include "ADM_inttype.h"
+#include "ADM_toolkitQt.h"
 
 extern uint8_t DIA_license(void);
 
-class Ui_aboutWindow : public QDialog
-{
-	Q_OBJECT
-
-private:
-	Ui_aboutDialog ui;
-
-public:
-	Ui_aboutWindow(QWidget* parent);
-
-private slots:
-	void licenseButton_clicked(bool);
-};
-
 Ui_aboutWindow::Ui_aboutWindow(QWidget* parent) : QDialog(parent)
 {
 	Q_INIT_RESOURCE(about);
@@ -59,7 +46,7 @@ void Ui_aboutWindow::licenseButton_clicked(bool)
 }
 
 uint8_t DIA_about(void)
-{	
+{
 	Ui_aboutWindow dialog(qtLastRegisteredDialog());
 	qtRegisterDialog(&dialog);
 
