@@ -15,20 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "ui_license.h"
-#include "default.h"
-#include "../ADM_toolkit/qtToolkit.h"
-
-class Ui_licenseWindow : public QDialog
-{
-	Q_OBJECT
-
-private:
-	Ui_licenseDialog ui;
-
-public:
-	Ui_licenseWindow(QWidget *parent);
-};
+#include "Q_license.h"
+#include "ADM_default.h"
+#include "ADM_toolkitQt.h"
 
 Ui_licenseWindow::Ui_licenseWindow(QWidget *parent) : QDialog(parent)
 {
