@@ -43,7 +43,6 @@ uint8_t DIA_Preferences(void)
 uint32_t olddevice,newdevice;
 
 uint32_t        use_odml=0;
-uint32_t	autosplit=0;
 uint32_t render;
 uint32_t useTray=0;
 uint32_t useMaster=0;
@@ -57,9 +56,7 @@ uint32_t playbackPriority=0;
 uint32_t downmix;
 uint32_t mpeg_no_limit=0;
 uint32_t msglevel=2;
-uint32_t activeXfilter=0;
 uint32_t mixer=0;
-char     *filterPath=NULL;
 char     *alsaDevice=NULL;
 uint32_t autovbr=0;
 uint32_t autoindex=0;
@@ -138,10 +135,6 @@ char     *globalGlyphName=NULL;
 		if(!prefs->get(PRIORITY_PLAYBACK, &playbackPriority))
                 playbackPriority=0;
 
-        // VCD/SVCD split point		
-        if(!prefs->get(SETTINGS_MPEGSPLIT, &autosplit))
-                autosplit=690;		
-                        
         // Open DML (Gmv)
         if(!prefs->get(FEATURE_USE_ODML, &use_odml))
           use_odml=0;
@@ -162,8 +155,6 @@ char     *globalGlyphName=NULL;
                 useNuv=0;
         // Get level of message verbosity
         prefs->get(MESSAGE_LEVEL,&msglevel);
-        // External filter
-         prefs->get(FILTERS_AUTOLOAD_ACTIVE,&activeXfilter);
         // Downmix default
         if(prefs->get(DOWNMIXING_PROLOGIC,&downmix)!=RC_OK)
         {       
@@ -235,8 +226,6 @@ char     *globalGlyphName=NULL;
 		framePriority.swallow(&menuIndexPriority);
 		framePriority.swallow(&menuPlaybackPriority);
 
-        diaElemUInteger autoSplit(&autosplit,QT_TR_NOOP("_Split MPEG files every (MB):"),10,4096);
-        
         diaElemToggle   togTagMp3(&alternate_mp3_tag,QT_TR_NOOP("_Use alternative tag for MP3 in .mp4"));
         diaMenuEntry videoMode[]={
                              {RENDER_GTK, getNativeRendererDesc(), NULL}
@@ -306,17 +295,6 @@ char     *globalGlyphName=NULL;
      framePP.swallow(&fdring);
      framePP.swallow(&postProcStrength);
      
-        // Filter path
-        if( prefs->get(FILTERS_AUTOLOAD_PATH, &filterPath) != RC_OK )
-#ifndef __WIN32
-               filterPath = ADM_strdup("/tmp");
-#else
-               filterPath = ADM_strdup("c:\\");
-#endif
-        diaElemDirSelect  entryFilterPath(&filterPath,QT_TR_NOOP("_Filter directory:"),QT_TR_NOOP("Select filter directory"));
-		diaElemToggle loadEx(&activeXfilter,QT_TR_NOOP("_Load external filters"));
-		loadEx.link(1, &entryFilterPath);
-
 		diaElemToggle togGlobalGlyph(&useGlobalGlyph, QT_TR_NOOP("Use _Global GlyphSet"));
 		diaElemFile  entryGLyphPath(0,&globalGlyphName,QT_TR_NOOP("Gl_yphSet:"), NULL, QT_TR_NOOP("Select GlyphSet file"));
 		togGlobalGlyph.link(1, &entryGLyphPath);
@@ -334,24 +312,12 @@ char     *globalGlyphName=NULL;
         diaElemTabs tabInput(QT_TR_NOOP("Input"),1,(diaElem **)diaInput);
         
         /* Output */
-        diaElem *diaOutput[]={&autoSplit,&openDml,&allowAnyMpeg,&togTagMp3};
-        diaElemTabs tabOutput(QT_TR_NOOP("Output"),4,(diaElem **)diaOutput);
+        diaElem *diaOutput[]={&openDml,&allowAnyMpeg,&togTagMp3};
+        diaElemTabs tabOutput(QT_TR_NOOP("Output"),3,(diaElem **)diaOutput);
         
         /* Audio */
-
-#if 0 //defined(ALSA_SUPPORT)
-        diaElem *diaAudio[]={&menuMixer,&menuVolume,&menuAudio,&entryAlsaDevice};
-        diaElemTabs tabAudio(QT_TR_NOOP("Audio"),4,(diaElem **)diaAudio);
-//#elif defined(OSS_SUPPORT)
-        diaElem *diaAudio[]={&menuMixer,&menuVolume,&menuAudio};
-        diaElemTabs tabAudio(QT_TR_NOOP("Audio"),3,(diaElem **)diaAudio);
-#endif
-
-#if 1
         diaElem *diaAudio[]={&menuMixer,&menuAudio};
         diaElemTabs tabAudio(QT_TR_NOOP("Audio"),2,(diaElem **)diaAudio);
-#endif
-
         
         /* Video */
         diaElem *diaVideo[]={&menuVideoMode,&framePP};
@@ -369,13 +335,9 @@ char     *globalGlyphName=NULL;
         diaElem *diaGlyph[]={&togGlobalGlyph,&entryGLyphPath};
         diaElemTabs tabGlyph(QT_TR_NOOP("Global GlyphSet"),2,(diaElem **)diaGlyph);
 
-        /* Xfilter tab */
-        diaElem *diaXFilter[]={&loadEx,&entryFilterPath};
-        diaElemTabs tabXfilter(QT_TR_NOOP("External Filters"),2,(diaElem **)diaXFilter);
-                                    
 // SET
-        diaElemTabs *tabs[]={&tabUser,&tabAuto,&tabInput,&tabOutput,&tabAudio,&tabVideo,&tabCpu,&tabThreading,&tabGlyph,&tabXfilter};
-        if( diaFactoryRunTabs(QT_TR_NOOP("Preferences"),10,tabs))
+        diaElemTabs *tabs[]={&tabUser,&tabAuto,&tabInput,&tabOutput,&tabAudio,&tabVideo,&tabCpu,&tabThreading,&tabGlyph};
+        if( diaFactoryRunTabs(QT_TR_NOOP("Preferences"),9,tabs))
 	{
         	
         	// cpu caps
@@ -443,8 +405,6 @@ char     *globalGlyphName=NULL;
                 prefs->set(DEVICE_VIDEODEVICE,render);
                 // Odml
                 prefs->set(FEATURE_USE_ODML, use_odml);
-				// Split
-                prefs->set(SETTINGS_MPEGSPLIT, autosplit);
                 
                 // number of threads
                 prefs->set(FEATURE_THREADING_LAVC, lavcThreads);
@@ -460,16 +420,13 @@ char     *globalGlyphName=NULL;
                 prefs->set(FEATURE_TRYAUTOIDX, useAutoIndex);
                 // Auto swap A/B
                 prefs->set(FEATURE_SWAP_IF_A_GREATER_THAN_B, useSwap);
-
+                //
+                prefs->set(MESSAGE_LEVEL,msglevel);
                 // Disable nuv sync
                 prefs->set(FEATURE_DISABLE_NUV_RESYNC, useNuv);
                 // Use tray while encoding
                 prefs->set(FEATURE_USE_SYSTRAY,useTray);
-                // Filter directory
-				prefs->set(FILTERS_AUTOLOAD_ACTIVE, activeXfilter);
 
-                if(filterPath)
-                  prefs->set(FILTERS_AUTOLOAD_PATH, filterPath);
                 // Alternate mp3 tag (haali)
                 prefs->set(FEATURE_ALTERNATE_MP3_TAG,alternate_mp3_tag);
 
@@ -484,7 +441,6 @@ char     *globalGlyphName=NULL;
             delete audioDeviceItems[i];
         }
 
-	ADM_dealloc(filterPath);
 	ADM_dealloc(globalGlyphName);
 
 	return 1;
