@@ -3,29 +3,18 @@
 
 
 */
-#include <config.h>
-
-#include <stdio.h>
-#include <stdlib.h>
+#include "config.h"
 
 
 #include "ADM_lavcodec.h"
 
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_codecs/ADM_codec.h"
-#include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_codecs/ADM_ffmpegConfig.h"
-#include "DIA_factory.h"
-#include "ADM_assert.h" 
-
-
+#include "ADM_default.h"
 
 #include "ADM_codecs/ADM_codec.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_assert.h" 
+
+  
 #include "DIA_factory.h"
-#include "../../ADM_encoder/adm_encmjpeg_param.h"
 
 /**
       \fn DIA_mjpegCodecSetting
