@@ -40,7 +40,6 @@
 #include "gtkgui.h"
 
 #include "ADM_outputs/oplug_avi/GUI_mux.h"
-#include "ADM_outputs/oplug_mpegFF/oplug_vcdff.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "prefs.h"
 #include "ADM_encoder/adm_encConfig.h"
@@ -57,10 +56,9 @@
 #include "ADM_videoFilter.h"
 #include "ADM_videoFilter_internal.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_codecs/ADM_ffmpeg.h"
-#include "ADM_libraries/ADM_libmpeg2enc/ADM_mpeg2enc.h"
 #include "ADM_video/ADM_vidMisc.h"
 #include "ADM_preview.h"
+
 AudioSource currentAudioSource = AudioAvi;
 AudioSource secondAudioSource = AudioNone;
 char *currentAudioName = NULL;
@@ -100,7 +98,6 @@ extern void saveMpegFile (char *name);
 //static void A_selectEncoder ( void );
 extern uint8_t A_SaveAudioDualAudio (const char *a);
 
-extern uint8_t ADM_aviUISetMuxer(  void );
 void A_Resync(void);
 void A_addJob(void);
 static void updateSecondAudioTrack (void);
@@ -123,7 +120,6 @@ extern uint8_t mpeg_passthrough(const char *name,ADM_OUT_FORMAT format );
 static void A_videoCheck( void);
 extern uint8_t parseScript(char *scriptname);
 static void	A_setPostproc( void );
-extern uint8_t ogmSave(const char  *name);
 //
 static uint8_t A_pass(char *name);
 uint8_t A_jumpToTime(uint32_t hh,uint32_t mm,uint32_t ss,uint32_t ms);
@@ -136,7 +132,6 @@ extern void videoCodecConfigureUI(int codecIndex = -1);
 extern void audioCodecChanged(int newcodec);
 extern void videoCodecChanged(int newcodec);
 extern void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate );
-extern uint8_t A_autoDrive(Action action);
 int ignore_change;
 
 extern uint8_t DIA_ocrGen(void);
@@ -207,16 +202,35 @@ int nw;
         case ACT_RECENT1:        
         case ACT_RECENT2:
         case ACT_RECENT3:
-                        const char **name;
-						char* fileName;
-                        int rank;
-                                name=prefs->get_lastfiles();
-                                rank=(int)action-ACT_RECENT0;
-                                ADM_assert(name[rank]);
-                                A_openAvi2 (name[rank], 0);
+		case ACT_RECENT4:
+		case ACT_RECENT5:
+		{
+			const char **name;
+			char* fileName;
+			int rank;
+			name=prefs->get_lastfiles();
+			rank=(int)action-ACT_RECENT0;
+			ADM_assert(name[rank]);
+			A_openAvi2 (name[rank], 0);
 
-                return;
-        case ACT_ViewMain: UI_toogleMain();return;
+			return;
+		}
+        case ACT_RECENTPROJECT0:
+        case ACT_RECENTPROJECT1:        
+        case ACT_RECENTPROJECT2:
+        case ACT_RECENTPROJECT3:
+		case ACT_RECENTPROJECT4:
+		case ACT_RECENTPROJECT5:
+		{
+			const char **name = prefs->getLastProjects();
+			int rank = (int)action - ACT_RECENTPROJECT0;
+
+			ADM_assert(name[rank]);
+			A_parseECMAScript(name[rank]);
+
+			return;
+		}
+		case ACT_ViewMain: UI_toogleMain();return;
         case ACT_ViewSide: UI_toogleSide();return;
         case ACT_DVB_Ocr:
         		DIA_ocrDvb();
@@ -296,10 +310,22 @@ int nw;
  #endif     
       prefs->save ();
       return;
-    case ACT_SetMuxParam:
-      ADM_aviUISetMuxer();
-      return;
-      break;
+	case ACT_SetMuxParam:
+	{
+		int index = UI_GetCurrentFormat();
+
+		for (int i = 0; i < ADM_FORMAT_MAX; i++)
+		{
+			if (ADM_allOutputFormat[index].format == index && ADM_allOutputFormat[index].muxerConfigure != NULL)
+			{
+				ADM_allOutputFormat[index].muxerConfigure();
+
+				break;
+			}
+		}
+
+		return;
+	}
     case ACT_Fast:
       ADM_assert(0);
       break;
@@ -389,16 +415,6 @@ int nw;
                 admPreview::update(curframe);
                 break;
 
-
-        case ACT_AUTO_VCD:
-        case ACT_AUTO_SVCD:
-        case ACT_AUTO_DVD:
-        case ACT_AUTO_PSP:
-        case ACT_AUTO_IPOD:
-        case ACT_AUTO_FLV:
-        case ACT_AUTO_PSP_H264:
-                A_autoDrive( action);
-                break;
      case ACT_TimeShift:
                 A_TimeShift();
                 break;
@@ -413,18 +429,7 @@ int nw;
 				DIA_Calculator(&a,&b );
 			}
     			break;
-    case ACT_SaveUnpackedMpeg4:
-      if(GUI_Question(QT_TR_NOOP("This is to be used to undo packed VOP on MPEG-4.\nContinue ?")))
-			{ 
-                          GUI_FileSelWrite (QT_TR_NOOP("Select AVI File to Write"), (SELFILE_CB *)A_SaveUnpackedVop);
-				
-			}
-    			break;
-			
-    case ACT_SaveOGM:
-                        GUI_FileSelWrite (QT_TR_NOOP("Select OGM File to Write"), (SELFILE_CB *)ogmSave);
-    			break;
-				
+
     case ACT_SaveWork:
       GUI_FileSelWrite (QT_TR_NOOP("Select Workbench to Save"), A_saveWorkbench);
 	  UI_refreshCustomMenu();
@@ -1846,6 +1851,9 @@ void A_parseECMAScript(const char *name){
       if( actual_workbench_file )
          ADM_dealloc(actual_workbench_file);
       actual_workbench_file = ADM_strdup(longname);
+
+	  prefs->setLastProject(longname);
+	  UI_updateRecentProjectsMenu();
    }
    ADM_dealloc(longname);
 }
@@ -2631,38 +2639,70 @@ uint8_t  ADMImage::saveAsBmp(const char *filename)
 */
 uint8_t  ADMImage::saveAsJpg(const char *filename)
 {
- ffmpegEncoderFFMjpeg *codec=NULL;
-  FILE *fd;
-  uint8_t *buffer=NULL;
-  uint32_t sz;
-  
+	AVCodecContext *context = avcodec_alloc_context();
+	AVCodec *codec = NULL;
+	uint8_t success = 0;
+	
+	if (context)
+	{
+		context->width = _width;
+		context->height = _height;
+		context->pix_fmt = PIX_FMT_YUVJ420P;
+		context->time_base = (AVRational){1, 25};
+		context->flags = CODEC_FLAG_QSCALE;
 
-        sz = _width*_height*3;
-        ADMBitstream bitstream(sz);
-        buffer=new uint8_t[sz];
-        bitstream.data=buffer;
-        codec=new  ffmpegEncoderFFMjpeg(_width,_height,FF_MJPEG)  ;
-        codec->init( 95,25000);
-        if(!codec->encode(this,&bitstream))
-        {
-                GUI_Error_HIG(QT_TR_NOOP("Cannot encode the frame"), NULL);
-                delete [] buffer;
-                delete codec;
-                return 0;
-        }
-        delete codec;
-        fd=fopen(filename,"wb");
-        if(!fd)
-        {
-                GUI_Error_HIG(QT_TR_NOOP("File error"),QT_TR_NOOP( "Cannot open \"%s\" for writing."), filename);
-                delete [] buffer;
-                return 0;
-        }
-        fwrite (buffer, bitstream.len, 1, fd);
-        fclose(fd);
-        delete [] buffer;
-        return 1;
+		codec = avcodec_find_encoder(CODEC_ID_MJPEG);
+
+		if (codec && avcodec_open(context, codec) < 0)
+			codec = NULL;
+
+		if (codec)
+		{
+			AVPicture picture;
+			int bufferSize = avpicture_fill(&picture, this->data, PIX_FMT_YUV420P, _width, _height);
+			uint8_t *buffer = new uint8_t[bufferSize];
+			AVFrame frame;
+
+			frame.quality = (int)floor(FF_QP2LAMBDA * 3 + 0.5);
+			frame.data[0] = picture.data[0];
+			frame.data[1] = picture.data[2];
+			frame.data[2] = picture.data[1];
+			frame.linesize[0] = picture.linesize[0];
+			frame.linesize[1] = picture.linesize[1];
+			frame.linesize[2] = picture.linesize[2];
+
+			int size = avcodec_encode_video(context, buffer, bufferSize, &frame);
+
+			if (size > 0)
+			{
+				FILE *fd = fopen(filename,"wb");
+
+				if (fd)
+				{
+					fwrite(buffer, size, 1, fd);
+					fclose(fd);
+
+					success = 1;
+				}
+				else
+					GUI_Error_HIG(QT_TR_NOOP("File error"), QT_TR_NOOP("Cannot open \"%s\" for writing."), filename);
+			}
+			else
+				GUI_Error_HIG(QT_TR_NOOP("Cannot encode the frame"), NULL);
+
+			delete [] buffer;
+		}
+	}
+
+	if (!context || !codec)
+		GUI_Error_HIG(QT_TR_NOOP("Cannot initialise JPEG encoder"), NULL);
+
+	if (context)
+		avcodec_close(context);
+	
+	return success;
 }
+
 /**
  *      \fn UI_getPreferredRender
  *      \brief Returns to render lib the user preferred rendering method
