@@ -1,7 +1,7 @@
 #ifndef _preferences_h_
 #define _preferences_h_
 
-#include "default.h"
+#include "ADM_default.h"
 
 #define RC_OK     1
 #define RC_FAILED 0
@@ -28,10 +28,6 @@ typedef enum {
 	CODECS_DVD_MATRIX,
 	CODECS_DVD_GOPSIZE,
 	CODECS_DVD_MAXBITRATE,
-	CODECS_XVID_ENCTYPE,
-	CODECS_XVID_QUANTIZER,
-	CODECS_XVID_BITRATE,
-	CODECS_XVID_FINALSIZE,
 	CODECS_PREFERREDCODEC,
 	FILTERS_SUBTITLE_FONTNAME,
 	FILTERS_SUBTITLE_CHARSET,
@@ -41,7 +37,10 @@ typedef enum {
 	FILTERS_SUBTITLE_VPERCENT,
 	FILTERS_SUBTITLE_SELFADJUSTABLE,
 	FILTERS_SUBTITLE_USEBACKGROUNDCOLOR,
-	SETTINGS_MPEGSPLIT,
+	FILTERS_AVSFILTER_AVS_SCRIPT,
+	FILTERS_AVSFILTER_AVS_LOADER,
+	FILTERS_AVSFILTER_PIPE_TIMEOUT,
+	FILTERS_AVSFILTER_DEBUG_MSG,
 	DEVICE_AUDIODEVICE,
 	DEVICE_AUDIO_ALSA_DEVICE,
 	DEVICE_VIDEODEVICE,
@@ -51,21 +50,21 @@ typedef enum {
 	LASTFILES_FILE2,
 	LASTFILES_FILE3,
 	LASTFILES_FILE4,
+	LASTFILES_FILE5,
+	LASTFILES_FILE6,
+	LASTPROJECT_FILE1,
+	LASTPROJECT_FILE2,
+	LASTPROJECT_FILE3,
+	LASTPROJECT_FILE4,
+	LASTPROJECT_FILE5,
+	LASTPROJECT_FILE6,
 	LASTDIR_READ,
 	LASTDIR_WRITE,
-	LAME_CLI,
-	PIPE_CMD,
-	PIPE_PARAM,
-	LAME_PATH,
-	TOOLAME_PATH,
-	LVEMUX_PATH,
-	REQUANT_PATH,
 	MESSAGE_LEVEL,
 	FEATURE_SWAP_IF_A_GREATER_THAN_B,
 	FEATURE_SVCDRES_PREFEREDSOURCERATIO,
 	FEATURE_SAVEPREFSONEXIT,
 	FEATURE_IGNORESAVEDMARKERS,
-	FEATURE_USE_LAVCODEC_MPEG2,
 	FEATURE_DISABLE_NUV_RESYNC,
 	FEATURE_TRYAUTOIDX,
 	FEATURE_USE_ODML,
@@ -73,16 +72,12 @@ typedef enum {
 	FEATURE_REUSE_2PASS_LOG,
 	FEATURE_AUDIOBAR_USES_MASTER,
 	FEATURE_THREADING_LAVC,
-	FEATURE_THREADING_X264,
-	FEATURE_THREADING_XVID,
 	FEATURE_CPU_CAPS,
 	FEATURE_MPEG_NO_LIMIT,
 	FEATURE_AUTO_BUILDMAP,
 	FEATURE_AUTO_REBUILDINDEX,
 	FEATURE_AUTO_UNPACK,
 	DOWNMIXING_PROLOGIC,
-	FILTERS_AUTOLOAD_PATH,
-	FILTERS_AUTOLOAD_ACTIVE,
 	FEATURE_ALTERNATE_MP3_TAG,
 	FEATURE_GLOBAL_GLYPH_ACTIVE,
 	FEATURE_GLOBAL_GLYPH_NAME,
@@ -94,7 +89,9 @@ typedef enum {
 
 class preferences {
 	private:
-		char *internal_lastfiles[5];
+		char *internal_lastfiles[7];
+		char *_lastProjects[7];
+
 		int save_xml_to_file();
 	public:
 		preferences();
@@ -125,6 +122,8 @@ class preferences {
                 int set(options option, const ADM_filename * val);
 		int set_lastfile(const char* file);
 		const char **get_lastfiles(void);
+		const char **getLastProjects(void);
+		int setLastProject(const char* file);
 };
 
 extern preferences *prefs;
