@@ -22,6 +22,86 @@
 #include "pixfmt.h"
 #include "pixdesc.h"
 
+#include "intreadwrite.h"
+
+void read_line(uint16_t *dst, const uint8_t *data[4], const int linesize[4],
+               const AVPixFmtDescriptor *desc, int x, int y, int c, int w, int read_pal_component)
+{
+    AVComponentDescriptor comp= desc->comp[c];
+    int plane= comp.plane;
+    int depth= comp.depth_minus1+1;
+    int mask = (1<<depth)-1;
+    int shift= comp.shift;
+    int step = comp.step_minus1+1;
+    int flags= desc->flags;
+
+    if (flags & PIX_FMT_BITSTREAM){
+        int skip = x*step + comp.offset_plus1-1;
+        const uint8_t *p = data[plane] + y*linesize[plane] + (skip>>3);
+        int shift = 8 - depth - (skip&7);
+
+        while(w--){
+            int val = (*p >> shift) & mask;
+            if(read_pal_component)
+                val= data[1][4*val + c];
+            shift -= step;
+            p -= shift>>3;
+            shift &= 7;
+            *dst++= val;
+        }
+    } else {
+        const uint8_t *p = data[plane]+ y*linesize[plane] + x*step + comp.offset_plus1-1;
+
+        while(w--){
+            int val;
+            if(flags & PIX_FMT_BE) val= AV_RB16(p);
+            else                   val= AV_RL16(p);
+            val = (val>>shift) & mask;
+            if(read_pal_component)
+                val= data[1][4*val + c];
+            p+= step;
+            *dst++= val;
+        }
+    }
+}
+
+void write_line(const uint16_t *src, uint8_t *data[4], const int linesize[4],
+                const AVPixFmtDescriptor *desc, int x, int y, int c, int w)
+{
+    AVComponentDescriptor comp = desc->comp[c];
+    int plane = comp.plane;
+    int depth = comp.depth_minus1+1;
+    int step  = comp.step_minus1+1;
+    int flags = desc->flags;
+
+    if (flags & PIX_FMT_BITSTREAM) {
+        int skip = x*step + comp.offset_plus1-1;
+        uint8_t *p = data[plane] + y*linesize[plane] + (skip>>3);
+        int shift = 8 - depth - (skip&7);
+
+        while (w--) {
+            *p |= *src++ << shift;
+            shift -= step;
+            p -= shift>>3;
+            shift &= 7;
+        }
+    } else {
+        int shift = comp.shift;
+        uint8_t *p = data[plane]+ y*linesize[plane] + x*step + comp.offset_plus1-1;
+
+        while (w--) {
+            if (flags & PIX_FMT_BE) {
+                uint16_t val = AV_RB16(p) | (*src++<<shift);
+                AV_WB16(p, val);
+            } else {
+                uint16_t val = AV_RL16(p) | (*src++<<shift);
+                AV_WL16(p, val);
+            }
+            p+= step;
+        }
+    }
+}
+
 const AVPixFmtDescriptor av_pix_fmt_descriptors[PIX_FMT_NB] = {
     [PIX_FMT_YUV420P] = {
         .name = "yuv420p",
@@ -112,16 +192,17 @@ const AVPixFmtDescriptor av_pix_fmt_descriptors[PIX_FMT_NB] = {
         },
     },
     [PIX_FMT_GRAY8] = {
-        .name = "gray8",
+        .name = "gray",
         .nb_components= 1,
         .log2_chroma_w= 0,
         .log2_chroma_h= 0,
         .comp = {
             {0,0,1,0,7},        /* Y */
         },
+        .flags = PIX_FMT_PAL,
     },
     [PIX_FMT_MONOWHITE] = {
-        .name = "monowhite",
+        .name = "monow",
         .nb_components= 1,
         .log2_chroma_w= 0,
         .log2_chroma_h= 0,
@@ -131,7 +212,7 @@ const AVPixFmtDescriptor av_pix_fmt_descriptors[PIX_FMT_NB] = {
         .flags = PIX_FMT_BITSTREAM,
     },
     [PIX_FMT_MONOBLACK] = {
-        .name = "monoblack",
+        .name = "monob",
         .nb_components= 1,
         .log2_chroma_w= 0,
         .log2_chroma_h= 0,
@@ -184,11 +265,11 @@ const AVPixFmtDescriptor av_pix_fmt_descriptors[PIX_FMT_NB] = {
         },
     },
     [PIX_FMT_XVMC_MPEG2_MC] = {
-        .name = "xvmc_mpeg2_mc",
+        .name = "xvmcmc",
         .flags = PIX_FMT_HWACCEL,
     },
     [PIX_FMT_XVMC_MPEG2_IDCT] = {
-        .name = "xvmc_mpeg2_idct",
+        .name = "xvmcidct",
         .flags = PIX_FMT_HWACCEL,
     },
     [PIX_FMT_UYVY422] = {
@@ -513,6 +594,29 @@ const AVPixFmtDescriptor av_pix_fmt_descriptors[PIX_FMT_NB] = {
             {0,1,1,0,4},        /* B */
         },
     },
+    [PIX_FMT_RGB444BE] = {
+        .name = "rgb444be",
+        .nb_components= 3,
+        .log2_chroma_w= 0,
+        .log2_chroma_h= 0,
+        .comp = {
+            {0,1,0,0,3},        /* R */
+            {0,1,1,4,3},        /* G */
+            {0,1,1,0,3},        /* B */
+        },
+        .flags = PIX_FMT_BE,
+    },
+    [PIX_FMT_RGB444LE] = {
+        .name = "rgb444le",
+        .nb_components= 3,
+        .log2_chroma_w= 0,
+        .log2_chroma_h= 0,
+        .comp = {
+            {0,1,2,0,3},        /* R */
+            {0,1,1,4,3},        /* G */
+            {0,1,1,0,3},        /* B */
+        },
+    },
     [PIX_FMT_BGR565BE] = {
         .name = "bgr565be",
         .nb_components= 3,
@@ -559,6 +663,29 @@ const AVPixFmtDescriptor av_pix_fmt_descriptors[PIX_FMT_NB] = {
             {0,1,1,0,4},        /* R */
         },
     },
+    [PIX_FMT_BGR444BE] = {
+        .name = "bgr444be",
+        .nb_components= 3,
+        .log2_chroma_w= 0,
+        .log2_chroma_h= 0,
+        .comp = {
+            {0,1,0,0,3},       /* B */
+            {0,1,1,4,3},       /* G */
+            {0,1,1,0,3},       /* R */
+        },
+        .flags = PIX_FMT_BE,
+     },
+    [PIX_FMT_BGR444LE] = {
+        .name = "bgr444le",
+        .nb_components= 3,
+        .log2_chroma_w= 0,
+        .log2_chroma_h= 0,
+        .comp = {
+            {0,1,2,0,3},        /* B */
+            {0,1,1,4,3},        /* G */
+            {0,1,1,0,3},        /* R */
+        },
+    },
     [PIX_FMT_VAAPI_MOCO] = {
         .name = "vaapi_moco",
         .log2_chroma_w = 1,
@@ -646,8 +773,51 @@ const AVPixFmtDescriptor av_pix_fmt_descriptors[PIX_FMT_NB] = {
         },
         .flags = PIX_FMT_BE,
     },
+    [PIX_FMT_DXVA2_VLD] = {
+        .name = "dxva2_vld",
+        .log2_chroma_w = 1,
+        .log2_chroma_h = 1,
+        .flags = PIX_FMT_HWACCEL,
+    },
 };
 
+static enum PixelFormat get_pix_fmt_internal(const char *name)
+{
+    enum PixelFormat pix_fmt;
+
+    for (pix_fmt = 0; pix_fmt < PIX_FMT_NB; pix_fmt++)
+        if (av_pix_fmt_descriptors[pix_fmt].name &&
+            !strcmp(av_pix_fmt_descriptors[pix_fmt].name, name))
+            return pix_fmt;
+
+    return PIX_FMT_NONE;
+}
+
+#if HAVE_BIGENDIAN
+#   define X_NE(be, le) be
+#else
+#   define X_NE(be, le) le
+#endif
+
+enum PixelFormat av_get_pix_fmt(const char *name)
+{
+    enum PixelFormat pix_fmt;
+
+    if (!strcmp(name, "rgb32"))
+        name = X_NE("argb", "bgra");
+    else if (!strcmp(name, "bgr32"))
+        name = X_NE("abgr", "rgba");
+
+    pix_fmt = get_pix_fmt_internal(name);
+    if (pix_fmt == PIX_FMT_NONE) {
+        char name2[32];
+
+        snprintf(name2, sizeof(name2), "%s%s", name, X_NE("be", "le"));
+        pix_fmt = get_pix_fmt_internal(name2);
+    }
+    return pix_fmt;
+}
+
 int av_get_bits_per_pixel(const AVPixFmtDescriptor *pixdesc)
 {
     int c, bits = 0;
